# coding=utf-8
"""
作者：vissy@zhu
"""
import setuptools

setuptools.setup(
    name="lyhapi",  # Replace with your own username
    version="0.0.5",
    author="vissyzhu",
    author_email="1209354095@qq.com",
    description="lyhcc information retriver",
    url="https://github.com/vissyzhu/lyhapi.git",
    license='MIT',
    packages=setuptools.find_packages(),
    zip_safe=False
)
